@@ -2,8 +2,9 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2022 Osimis S.A., Belgium
- * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2017-2023 Osimis S.A., Belgium
+ * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -70,6 +71,7 @@ namespace Orthanc
 
 #if ORTHANC_ENABLE_CURL == 1
     static int SetHttpCredentials(lua_State *state);
+    static int SetHttpTimeout(lua_State *state);
     static int CallHttpPostOrPut(lua_State *state,
                                  HttpMethod method);
     static int CallHttpGet(lua_State *state);
@@ -105,11 +107,6 @@ namespace Orthanc
 
     bool IsExistingFunction(const char* name);
 
-#if ORTHANC_ENABLE_CURL == 1
-    void SetHttpCredentials(const char* username,
-                            const char* password);
-#endif
-
     void RegisterFunction(const char* name,
                           lua_CFunction func);
 
