@@ -3,7 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,6 +21,8 @@
  **/
 
 
+#define PLUGIN_NAME "sample"
+
 #include <orthanc/OrthancCPlugin.h>
 
 #include <string.h>
@@ -578,9 +581,9 @@ ORTHANC_PLUGINS_API int32_t OrthancPluginInitialize(OrthancPluginContext* c)
     
   
   /* Declare several properties of the plugin */
-  OrthancPluginSetRootUri(context, "/plugin/hello");
-  OrthancPluginSetDescription(context, "This is the description of the sample plugin that can be seen in Orthanc Explorer.");
-  OrthancPluginExtendOrthancExplorer(context, "alert('Hello Orthanc! From sample plugin with love.');");
+  OrthancPluginSetRootUri2(context, PLUGIN_NAME, "/plugin/hello");
+  OrthancPluginSetDescription2(context, PLUGIN_NAME, "This is the description of the sample plugin that can be seen in Orthanc Explorer.");
+  OrthancPluginExtendOrthancExplorer2(context, PLUGIN_NAME, "alert('Hello Orthanc! From sample plugin with love.');");
 
   customError = OrthancPluginRegisterErrorCode(context, 4, 402, "Hello world");
   
@@ -602,7 +605,7 @@ ORTHANC_PLUGINS_API void OrthancPluginFinalize()
 
 ORTHANC_PLUGINS_API const char* OrthancPluginGetName()
 {
-  return "sample";
+  return PLUGIN_NAME;
 }
 
 
