@@ -3,7 +3,8 @@
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
  * Copyright (C) 2017-2023 Osimis S.A., Belgium
- * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,11 +21,14 @@
  **/
 
 
+#define ORTHANC_PLUGIN_NAME "multitenant-dicom"
+
 #include "MultitenantDicomServer.h"
 
 #include "../../../../OrthancFramework/Sources/DicomParsing/FromDcmtkBridge.h"
 #include "../../../../OrthancFramework/Sources/Logging.h"
 #include "../../../../OrthancFramework/Sources/OrthancException.h"
+#include "../../../../OrthancFramework/Sources/OrthancFramework.h"
 
 #include "../Common/OrthancPluginCppWrapper.h"
 
@@ -88,11 +92,37 @@ static OrthancPluginErrorCode OnChangeCallback(OrthancPluginChangeType changeTyp
 }
 
 
+static void MyInitialization(const OrthancPlugins::OrthancConfiguration& config)
+{
+  static const char* const LOCALE = "Locale";
+  static const char* const DEFAULT_ENCODING = "DefaultEncoding";
+
+  /**
+   * This function is a simplified version of function
+   * "Orthanc::OrthancInitialize()" that is executed when starting the
+   * Orthanc server.
+   **/
+
+  Orthanc::InitializeFramework(config.GetStringValue(LOCALE, ""), false /* loadPrivateDictionary */);
+
+  std::string encoding;
+  if (config.LookupStringValue(encoding, DEFAULT_ENCODING))
+  {
+    Orthanc::SetDefaultDicomEncoding(Orthanc::StringToEncoding(encoding.c_str()));
+  }
+  else
+  {
+    Orthanc::SetDefaultDicomEncoding(Orthanc::ORTHANC_DEFAULT_DICOM_ENCODING);
+  }
+}
+
+
 extern "C"
 {
   ORTHANC_PLUGINS_API int32_t OrthancPluginInitialize(OrthancPluginContext* context)
   {
-    OrthancPlugins::SetGlobalContext(context);
+    OrthancPlugins::SetGlobalContext(context, ORTHANC_PLUGIN_NAME);
+    Orthanc::Logging::InitializePluginContext(context, ORTHANC_PLUGIN_NAME);
 
     /* Check the version of the Orthanc core */
     if (OrthancPluginCheckVersion(OrthancPlugins::GetGlobalContext()) == 0)
@@ -107,32 +137,14 @@ extern "C"
       return -1;
     }
 
-#if ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 7, 2)
-    Orthanc::Logging::InitializePluginContext(context);
-#else
-    Orthanc::Logging::Initialize(context);
-#endif
-
-    if (!OrthancPlugins::CheckMinimalOrthancVersion(1, 12, 0))
-    {
-      OrthancPlugins::ReportMinimalOrthancVersion(1, 12, 0);
-      return -1;
-    }
-
-    // For static builds, this is not required - but does not harm - because the dictionary seems to be shared between the Orthanc Core and the plugin.
-    // For dynamic builds, this is however required.  See https://discourse.orthanc-server.org/t/dimse-failure-using-multitenant-plugin/3665
-    Orthanc::FromDcmtkBridge::InitializeDictionary(false /* loadPrivateDictionary */);
-
-    /* Disable "gethostbyaddr" (which results in memory leaks) and use raw IP addresses */
-    dcmDisableGethostbyaddr.set(OFTrue);
-
-    OrthancPluginSetDescription(context, "Multitenant plugin for Orthanc.");
+    OrthancPluginSetDescription2(context, ORTHANC_PLUGIN_NAME, "Multitenant plugin for Orthanc.");
 
     OrthancPluginRegisterOnChangeCallback(context, OnChangeCallback);
     
     try
     {
       OrthancPlugins::OrthancConfiguration globalConfig;
+      MyInitialization(globalConfig);
 
       OrthancPlugins::OrthancConfiguration pluginConfig;
       globalConfig.GetSection(pluginConfig, KEY_MULTITENANT_DICOM);
@@ -181,12 +193,14 @@ extern "C"
         }
       }
     }
+
+    Orthanc::FinalizeFramework();
   }
 
 
   ORTHANC_PLUGINS_API const char* OrthancPluginGetName()
   {
-    return "multitenant-dicom";
+    return ORTHANC_PLUGIN_NAME;
   }
 
 
